.. llvmpy documentation master file, created by
   sphinx-quickstart on Wed Aug  8 17:33:58 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation for llvmpy
=================

Contents:

.. toctree::
   :titlesonly:
   :maxdepth: 2

   doc/userguide.rst
   doc/llvm_cbuilder.rst
   doc/llpython/index.rst
   doc/examples.rst
   doc/llvmcore.rst 
   doc/llvmee.rst
   doc/llvmpasses.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

